import http from "../../utils/http";

// pages/asset-bind/asset-bind.js
Page({

    /**
     * 页面的初始数据
     */
    data: {
      dateVisible: false,
      catVisible: false,
      date: new Date().getTime(), // 支持时间戳传入
      start: '1994-01-01 00:00:00',
      key: '',
      buyError: false,
      serverError: false,
      presentError: false,
      form: {},
      fileList: [],
      catTree: [],
      keys: {
        label: 'catName',
        value: 'catId',
        children: 'children',
      },
      url: {
        add: '',
        tree: '/v1/category/tree',
        client: '/v1/ams/client',
        dept: '/v1/ams/clientDept',
        asset: '/v1/ams/asset',
      }
    },

    showPicker(e) {
      this.setData({
        dateVisible: true,
      });
    },
    showCascader() {
      this.setData({ 
        catVisible: true 
      });
    },
    hidePicker() {
      this.setData({
        dateVisible: false,
      });
    },
    onConfirm(e) {
      const { value } = e.detail;
      const fieldName = 'form.buyTime'
      this.setData({
        [`${fieldName}`]: value,
      });
      this.hidePicker();
    },
    onNumberInput(e) {
      const { value } = e.detail;  // 获取值
      const { key, fieldName } = e.target.dataset // 获取检测的表单
      const error = this.data[`${key}Error`];  // 现在的error
      const isNumber = /^\d+(\.\d+)?$/.test(value);  // 校验正则是否是数字
      if (error === isNumber) {
        this.setData({
          key,
          [`${key}Error`]: !isNumber,
        });
      } else {
        this.setData({
          [`${fieldName}`]: value
        })
      }
    },
    handleInputChange(e) {
      const { value } = e.detail;
      const { fieldName } = e.target.dataset;
      this.setData({
        [`${fieldName}`]: value
      })
    },
    onIconTap(e) {
      const _this = this
      wx.scanCode({
        success (res) {
          const { result } = res
          const fieldName = 'form.asCode'
          _this.setData({
            [`${fieldName}`]: result
          })
        }
      })
    },
    onSumbit() {
      if (this.data.form.assetId) {
        // 编辑
        http.put(this.data.url.asset, this.data.form).then(res => {
          wx.redirectTo({
            url: '../asset-list/asset-list'
          })
        })
      } else {
        // 新增
        http.post(this.data.url.asset, this.data.form).then(res => {
          wx.redirectTo({
            url: '../asset-list/asset-list'
          })
        })
      }
      // wx.showModal({
      //   title: '提交json一览',
      //   content: JSON.stringify(this.data.form)
      // })
    },
    
    handleAdd(e) {
      const { fileList } = this.data;
      const { files } = e.detail;
      // 方法1：选择完所有图片之后，统一上传，因此选择完就直接展示
      this.setData({
        fileList: [...fileList, ...files], // 此时设置了 fileList 之后才会展示选择的图片
      });
      const _this = this
      wx.uploadFile({
        url: getApp().globalData.host + '/file/upload', // 仅为示例，非真实的接口地址
        filePath: files[0].url, //静态图片路径
        name: 'file',//请求接口需求的参数格式
        formData: { fileBucket: getApp().globalData.fileBucket, fileLocation: 3, fileObjectName: '100001/100/' }, // 这里根据后台服务需求来替换
        success: function (res) {
          const {data} = res
          const fieldName = 'form.mainImg'
          const fileContent = 'form.fileContent'
          const fileRes = JSON.parse(data).data
          _this.setData({
            [`${fileContent}`]: JSON.stringify([{
              status: 'done',
              url: fileRes.accessUrl,
              uid: fileRes.fileId,
              name: fileRes.fileOriginName,
            }]),
            [`${fieldName}`]: fileRes.accessUrl
          })
        }
      })
      // 方法2：每次选择图片都上传，展示每次上传图片的进度
      // files.forEach(file => this.uploadFile(file))
    },
    uploadFile(file) {
      const { fileList } = this.data;

      this.setData({
        fileList: [...fileList, { ...file, status: 'loading' }],
      });
      const { length } = fileList;

      const task = wx.uploadFile({
        url: getApp().globalData.host + '/file/upload', // 仅为示例，非真实的接口地址
        filePath: file.url,
        name: 'file',
        formData: { fileBucket: 'asset', fileLocation: 3, fileObjectName: '10000' + '/' }, // 这里根据后台服务需求来替换
        success: () => {
          this.setData({
            [`fileList[${length}].status`]: 'done',
          });
        },
      });
      task.onProgressUpdate((res) => {
        this.setData({
          [`fileList[${length}].percent`]: res.progress,
        });
      });
    },
    handleRemove(e) {
      const { index } = e.detail;
      const { fileList } = this.data;
      const fieldName = 'form.mainImg'
      fileList.splice(index, 1);
      this.setData({
        fileList,
        [`${fieldName}`]: ''
      });
    },
  

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad(options) {
      const detail = options?.detail
      if (detail) {
        let b = JSON.parse(detail)
        if (b.mainImg !== '') {
          this.setData({
            fileList: [{
              url: b.mainImg,
              name: 'uploaded1.png',
              type: 'image'
            }]
          })
        }
        this.setData({
          form: JSON.parse(detail)
        })
      }
      this.initCat()
      this.initClient()
    },
    initCat() {
      http.get(this.data.url.tree).then(res => {
        this.setData({
          catTree: res
        })
      })
    },
    initClient() {
      http.get(this.data.url.client).then(res => {
        this.setData({
          clientList: res.map(i => {
            return {
              label: i.name,
              value: i.tenantId
            }
          })
        })
      })
    },
    onCatChange(e) {
      const { selectedOptions } = e.detail;
      const catName = 'form.catName'
      const catId = 'form.catId'
      this.setData({
        [`${catName}`]: selectedOptions.slice(0, -1).map((item) => item.catName).join('/'),
        [`${catId}`]: selectedOptions[selectedOptions.length - 2].catId
      });
    },
    onClientPicker() {
      this.setData({ 
        clientVisible: true 
      });
    },
    onDeptPicker() {
      if (!this.data.form.tenantId) {
        wx.showToast({
          title: '请先选择公司',
          icon: 'error',
        })
      } else {
        this.initDept()
        this.setData({ 
          deptVisible: true 
        });
      }
    },
    initDept() {
      http.get(this.data.url.dept, {tenantId: this.data.form.tenantId}).then(res => {
        this.setData({
          deptList: res.map(i => {
            return {
              label: i.deptName,
              value: i.deptId
            }
          })
        })
      })
    },
    onPickerChange(e) {
      const { key, mark } = e.currentTarget.dataset;
      const { value, label } = e.detail;
      this.setData({
        [`${mark}Visible`]: false,
        [`${key}`]: value[0],
        [`form.${mark}Name`]: label[0],
      });
    },

    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady() {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow() {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide() {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload() {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh() {

    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom() {

    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage() {

    }
})