// pages/asset-list/asset-list.js
import http from '../../utils/http';
Page({
    /**
     * 页面的初始数据
     */
    data: {
      url: {
        page: '/v1/ams/asset/page',
        dictItem: '/v1/pub/dictItem',
        getDetailByCode: '/v1/ams/asset/scan'
      },
      pageNo: 1,
      pageSize: 6,
      sorter: {
        value: 'default',
        options: [
          {
            value: 'default',
            label: '默认排序',
          },
          {
            value: 'name',
            label: '名称排序',
          },
        ],
      },
      status: {
        value: '',
        options: [
          {
            value: '',
            label: '全部资产',
          },
          {
            value: '10',
            label: '在用',
          },
          {
            value: '99',
            label: '闲置',
          },
          {
            value: '11',
            label: '借用',
          },
          {
            value: '14',
            label: '报废',
          },
          {
            value: '13',
            label: '调拨中',
          },
          {
            value: '12',
            label: '维修中',
          },
        ],
      },
      asList: [],
      timeId: 0
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad(options) {
      this.initDict(options)
    },
    initDict(options) {
      const fieldName = 'status.value'
      http.get(this.data.url.dictItem, {dictCode: 'ZCZT'}).then(res => {
        this.setData({
          asStateList: res,
          [`${fieldName}`]: options.asState == 0 ? '' : options.asState
        })
        this.initAssetList()
      })
    },
    initAssetList() {
      let params = {
        pageNo: this.data.pageNo,
        pageSize: this.data.pageSize,
        asState: this.data.status.value,
        name: this.data.name
      }
      http.post(this.data.url.page, params).then(res => {
        this.setData({
          asList: this.data.asList.concat(res.records.map(i => {
            return {
              asStateName: this.data.asStateList.find(j => j.itemValue == i.asState).itemText,
              ...i
            } 
          }))
        })
      })
    },
    onTapAs(e) {
      const ascode  = e.currentTarget.dataset.ascode
      http.get(this.data.url.getDetailByCode, {asCode: ascode}).then(res => {
        if (res) {
          wx.navigateTo({
            url: '../asset-detail/asset-detail?detail=' + JSON.stringify(res),
          })
        }
      })
    },
    onStatusChange(e) {
      const { value } = e.detail
      const fieldName = 'status.value'
      this.setData({
        [`${fieldName}`]: value,
        pageNo: 1,
        asList: []
      })
      this.initAssetList()
    },
    handleAdd() {
      wx.navigateTo({
        url: '../asset-bind/asset-bind'
      })
    },
    handleScan() {
      const _this = this
      wx.scanCode({
        success (res) {
          const { result } = res
          http.get(_this.data.url.getDetailByCode, {asCode: result}).then(res => {
            if (res) {
              wx.navigateTo({
                url: '../asset-detail/asset-detail?detail=' + JSON.stringify(res),
              })
            }
          })
        },
      })
    },
    handleNameSearch(e) {
      const { value } = e.detail
      this.setData({
        name: value,
        pageNo: 1,
        asList: []
      })
      clearTimeout(this.data.timeId) //清除定时器
      this.data.timeId = setTimeout(()=>{     
        this.initAssetList() //发送请求，间隔时间为1s
      }, 1000)
    },
    /**
     * 生命周期函数--监听页面初次渲染完成
     */
    onReady() {

    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow() {

    },

    /**
     * 生命周期函数--监听页面隐藏
     */
    onHide() {

    },

    /**
     * 生命周期函数--监听页面卸载
     */
    onUnload() {

    },

    /**
     * 页面相关事件处理函数--监听用户下拉动作
     */
    onPullDownRefresh() {
      console.log('下拉')
    },

    /**
     * 页面上拉触底事件的处理函数
     */
    onReachBottom() {
      this.setData({
        pageNo: this.data.pageNo + 1
      })
      this.initAssetList()
    },

    /**
     * 用户点击右上角分享
     */
    onShareAppMessage() {

    }
})