const http = {
  // 通用post方法
  post: function(url, data) {
    wx.showLoading()
    return new Promise((resolve, reject) => {
      wx.request({
        url: getApp().globalData.host + url,
        method: 'POST',
        data: data,
        dataType: 'json',
        header: {
          'content-type': 'application/json' // 默认值
        },
        success: (res) => {
          const { statusCode } = res
          if (statusCode === 200) {
            const { data, code, message } = res.data
            if (code !== 99200) {
              handleError(message)
            }
            resolve(data)
          } else {
            reject(res)
          }
          wx.hideLoading()
        },
      })
    })
  },
  // 通用get方法
  get: function(url, data) {
    wx.showLoading()
    return new Promise((resolve, reject) => {
      wx.request({
        url: getApp().globalData.host + url,
        method: 'GET',
        data: data,
        headers: {
          'Content-Type': 'application/json;charset=UTF-8'
        },
        success: (res) => {
          const { statusCode } = res
          if (statusCode === 200) {
            const { data, code, message } = res.data
            if (code !== 99200) {
              handleError(message)
            }
            resolve(data)
          } else {
            reject(res)
          }
          wx.hideLoading()
        }
      })
    })
  },
  put: function(url, data) {
    wx.showLoading()
    return new Promise((resolve, reject) => {
      wx.request({
        url: getApp().globalData.host + url,
        method: 'PUT',
        data: data,
        headers: {
          'Content-Type': 'application/json;charset=UTF-8'
        },
        success: (res) => {
          const { statusCode } = res
          if (statusCode === 200) {
            const { data, code, message } = res.data
            if (code !== 99200) {
              handleError(message)
            }
            resolve(data)
          } else {
            reject(res)
          }
          wx.hideLoading()
        }
      })
    })
  },
}

// 错误处理方法
function handleError(err) {
  wx.showToast({
    title: err,
    icon: 'error',
  })
}

export default http
